Learn R Programming

hacksig (version 0.1.2)

get_sig_genes: Get signature gene identifiers

Description

Obtain gene signatures implemented in hacksig as a named list of gene symbols.

Usage

get_sig_genes(keywords = "all")

Arguments

keywords

A character vector indicating keywords for a group of signatures. The default ("all") will cause the function to check for all the signatures implemented in hacksig.

Value

A named list of gene signatures.

See Also

get_sig_info() to get valid keywords for signatures.

Examples

Run this code
# NOT RUN {
get_sig_genes()
get_sig_genes("estimate")
# }

Run the code above in your browser using DataLab