Obtain gene signatures implemented in hacksig as a named list of gene symbols.
Usage
get_sig_genes(keywords = "all")
Arguments
keywords
A character vector indicating keywords for a group of signatures.
The default ("all") will cause the function to check for all the signatures
implemented in hacksig.