get_sig_info() returns information about all gene signatures implemented in
hacksig.
Usage
get_sig_info()
Arguments
Value
A tibble with one row per signature and four columns:
signature_id, a unique identifier associated to a signature;
signature_keywords, valid keywords to use in the signatures argument of
hack_sig() and check_sig() as well as in the keywords argument of
get_sig_genes();
publication_doi, the original publication DOI;
description, a brief description about the signature.